@@ -6,7 +6,7 @@ from typing import List, Tuple, TYPE_CHECKING, Optional, Callable, Awaitable, Un
 
 from .util import get_message_mentions
 from .channel import Channel, channels
-from .regex import RE_PRIVMSG, RE_WHISPER, RE_USER_JOIN, RE_USERNOTICE, RE_USER_PART, RE_NOTICE, RE_TIMEOUT_DURATION
+from .regex import RE_PRIVMSG, RE_WHISPER, RE_USER_JOIN, RE_USERNOTICE, RE_USER_PART, RE_NOTICE, RE_TIMEOUT_DURATION, RE_USER_STATE, RE_ROOM_STATE
 from .enums import MessageType
 from .util import split_message
 from .tags import Tags
@@ -132,7 +132,9 @@ class Message:
          or self._parse_whisper()
          or self._parse_user_join()
          or self._parse_user_part()
-         or self._check_ping())
+         or self._check_ping()
+         or self._parse_user_state()
+         or self._parse_room_state())
 
         if self.parts and any(p in emotes for p in self.parts):
             self.emotes = tuple(emotes[p] for p in self.parts if p in emotes)
@@ -144,6 +146,24 @@ class Message:
                        if self.tags is not None
                        else None)
 
+    def _parse_user_state(self):
+        m = RE_USER_STATE.search(self.raw_msg)
+        if m:
+            self.channel = self._get_channel_or_default(m['channel'])
+            self.tags = Tags(m['tags'])
+            self.type = MessageType.USER_STATE
+
+        return bool(m)
+
+    def _parse_room_state(self):
+        m = RE_ROOM_STATE.search(self.raw_msg)
+        if m:
+            self.channel = self._get_channel_or_default(m['channel'])
+            self.tags = Tags(m['tags'])
+            self.type = MessageType.ROOM_STATE
+
+        return bool(m)
+
     def _parse_user_part(self) -> bool:
         m = RE_USER_PART.search(self.raw_msg)
         if m:
@@ -289,6 +309,20 @@ class Message:
         tags = self.tags
         return tags is not None and all((tags.display_name, self.content is not None, tags.id, tags.user_id, self.author))
 
+    @property
+    def has_broadcaster_badge(self):
+        return bool(self.tags.badges.get('broadcaster'))
+
+    @property
+    def has_moderator_badge(self):
+        return bool(self.tags.badges.get('moderator'))
+
+    def has_badge(self, badge_name: str) -> bool:
+        return badge_name in self.tags.badges
+
+    def get_badge_value(self, badge_name: str) -> Optional[Union[str, int]]:
+        return self.tags.badges.get(badge_name)
+
     async def send_command(self, msg: str = '', whisper=False):
         warnings.warn('twitch moved commands to API Calls, sending them via chat commands using IRC no longer works,'
                       ' instead use the `send_` functions from the twitchbot import', DeprecationWarning, stacklevel=2)
