@@ -23,7 +23,7 @@ from .enums import Event
 from .events import trigger_event, AsyncEventWrapper
 from .message import Message
 from .shared import get_bot
-from .util import temp_syspath, get_py_files, get_file_name
+from .util import temp_syspath, get_py_files, get_file_name, add_nameless_task
 from .translations import translate
 
 __all__ = ('ensure_mods_folder_exists', 'Mod', 'register_mod', 'trigger_mod_event', 'mods',
@@ -253,6 +253,25 @@ class Mod:
         triggered AFTER the bot creates all defined tables in the database
         this event should be used when you need to do database operations as soon as possible on bot startup
         """
+    
+    async def on_user_state(self, msg: 'Message'):
+        """
+        Triggered when twitch sends a USERSTATE update to the bot account
+        
+        Useful for tracking if the bot is a moderator or not (via 'moderator' badge)
+        """
+    async def on_room_state(self, msg: 'Message'):
+        """
+        Triggered when twitch sends a ROOMSTATE update to the bot account
+        
+        Tags:
+            emote-only (0 = disabled)
+            followers-only (-1 = disabled)
+            r9k (0 = disabled)
+            slow (0 = disabled)
+            subs-only (0 = disabled)
+            
+        """
 
     # endregion
 
@@ -270,7 +289,7 @@ def register_mod(mod: Mod) -> bool:
         return False
 
     mods[mod.name_or_class_name()] = mod
-    get_event_loop().create_task(mod.loaded())
+    add_nameless_task(mod.loaded())
     return True
 
 
@@ -283,7 +302,7 @@ def unregister_mod(mod: Mod) -> bool:
     if mod.name_or_class_name() not in mods:
         return False
 
-    get_event_loop().create_task(mod.unloaded())
+    add_nameless_task(mod.unloaded())
     del mods[mod.name_or_class_name()]
     return True
 
@@ -396,6 +415,8 @@ def iter_mods_from_directory(fullpath, predicate: Callable[[str, Any], bool] = N
                     yield obj
 
 
+
+
 def reload_mod(mod_name: str):
     mod = mods.get(mod_name)
     if mod is None:
@@ -426,9 +447,9 @@ def reload_mod(mod_name: str):
                             var.unregister()
 
                     # trigger events
-                    get_event_loop().create_task(trigger_mod_event(Event.on_mod_reloaded, reloaded_mod))
-                    get_event_loop().create_task(get_bot().on_mod_reloaded(reloaded_mod))
-                    get_event_loop().create_task(trigger_event(Event.on_mod_reloaded, reloaded_mod))
+                    add_nameless_task(trigger_mod_event(Event.on_mod_reloaded, reloaded_mod))
+                    add_nameless_task(get_bot().on_mod_reloaded(reloaded_mod))
+                    add_nameless_task(trigger_event(Event.on_mod_reloaded, reloaded_mod))
                     return True
 
     except Exception as e:
